# Image-Processing-HG

Description 

    Este projeto é um fork do projeto desenvolvido no Bootcamp Cognizant Cloud Data Engineer 2, modulo apresentado pela desenvolvedora karina Kato. 

    Este package consiste na reprodução de um pacote de processamento de imagens em python e sua publicação utilizando o Pypi. 

The package image-processing-hg is used to:

	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image

	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_processing

```bash
pip install image-processing-hg
```

## Usage

```python
from image-processing-hg.processing import transformation
transformation.resize_image()
```

## Author
Huguemberg M. 
by Karina Kato

## License
[MIT](https://choosealicense.com/licenses/mit/)